@@ -46,24 +46,24 @@
 #'         lines(p$x, p$y)
 #'       }
 #'     }
-#'  
+#'
 #'     # string2stroke() converts a text to strokes
 #'     d_stroke <- string2stroke("TEXT", family, weight, style)
 #'     if (nrow(d_stroke) > 0) {
 #'       plot(d_stroke$x, d_stroke$y)
-#'  
+#'
 #'       # The stroke is split into triangles, which can be distinguished by `triangle_id`
 #'       set.seed(2)
 #'       for (p in split(d_stroke, d_stroke$triangle_id)) {
 #'         polygon(p$x, p$y, col = rgb(runif(1), runif(1), runif(1), 0.8))
 #'       }
 #'     }
-#'  
+#'
 #'     # string2fill() converts a text to filled polygons
 #'     d_fill <- string2fill("TEXT", family, weight, style)
 #'     if (nrow(d_fill) > 0) {
 #'       plot(d_fill$x, d_fill$y)
-#'  
+#'
 #'       # The polygon is split into triangles, which can be distinguished by `triangle_id`
 #'       set.seed(2)
 #'       for (p in split(d_fill, d_fill$triangle_id)) {
@@ -75,15 +75,27 @@
 #'
 #' @export
 string2path <- function(
-    text,
-    font,
-    font_weight = c("normal", "thin", "extra_thin", "light", "medium", "semibold", "bold", "extra_bold", "black"),
-    font_style = c("normal", "italic", "oblique"),
-    tolerance = 0.00005
+  text,
+  font,
+  font_weight = c(
+    "normal",
+    "thin",
+    "extra_thin",
+    "light",
+    "medium",
+    "semibold",
+    "bold",
+    "extra_bold",
+    "black"
+  ),
+  font_style = c("normal", "italic", "oblique"),
+  tolerance = 0.00005
 ) {
   if (is_font_file(font)) {
     if (!missing(font_weight) || !missing(font_style)) {
-      cli::cli_warn("{.arg font_weight} and {.arg font_style} are ignored when extracting a font file.")
+      cli::cli_warn(
+        "{.arg font_weight} and {.arg font_style} are ignored when extracting a font file."
+      )
     }
 
     font <- path.expand(font)
@@ -92,23 +104,37 @@ string2path <- function(
     font_weight <- match.arg(font_weight)
     font_style <- match.arg(font_style)
 
-    tibble::as_tibble(string2path_family(text, font, font_weight, font_style, tolerance))
+    tibble::as_tibble(
+      string2path_family(text, font, font_weight, font_style, tolerance)
+    )
   }
 }
 
 #' @rdname string2path
 #' @export
 string2stroke <- function(
-    text,
-    font,
-    font_weight = c("normal", "thin", "extra_thin", "light", "medium", "semibold", "bold", "extra_bold", "black"),
-    font_style = c("normal", "italic", "oblique"),
-    tolerance = 0.00005,
-    line_width = 0.03
+  text,
+  font,
+  font_weight = c(
+    "normal",
+    "thin",
+    "extra_thin",
+    "light",
+    "medium",
+    "semibold",
+    "bold",
+    "extra_bold",
+    "black"
+  ),
+  font_style = c("normal", "italic", "oblique"),
+  tolerance = 0.00005,
+  line_width = 0.03
 ) {
   if (is_font_file(font)) {
     if (!missing(font_weight) || !missing(font_style)) {
-      cli::cli_warn("{.arg font_weight} and {.arg font_style} are ignored when extracting a font file.")
+      cli::cli_warn(
+        "{.arg font_weight} and {.arg font_style} are ignored when extracting a font file."
+      )
     }
 
     font <- path.expand(font)
@@ -117,22 +143,43 @@ string2stroke <- function(
     font_weight <- match.arg(font_weight)
     font_style <- match.arg(font_style)
 
-    tibble::as_tibble(string2stroke_family(text, font, font_weight, font_style, tolerance, line_width))
+    tibble::as_tibble(
+      string2stroke_family(
+        text,
+        font,
+        font_weight,
+        font_style,
+        tolerance,
+        line_width
+      )
+    )
   }
 }
 
 #' @rdname string2path
 #' @export
 string2fill <- function(
-    text,
-    font,
-    font_weight = c("normal", "thin", "extra_thin", "light", "medium", "semibold", "bold", "extra_bold", "black"),
-    font_style = c("normal", "italic", "oblique"),
-    tolerance = 0.00005
+  text,
+  font,
+  font_weight = c(
+    "normal",
+    "thin",
+    "extra_thin",
+    "light",
+    "medium",
+    "semibold",
+    "bold",
+    "extra_bold",
+    "black"
+  ),
+  font_style = c("normal", "italic", "oblique"),
+  tolerance = 0.00005
 ) {
   if (is_font_file(font)) {
     if (!missing(font_weight) || !missing(font_style)) {
-      cli::cli_warn("{.arg font_weight} and {.arg font_style} are ignored when extracting a font file.")
+      cli::cli_warn(
+        "{.arg font_weight} and {.arg font_style} are ignored when extracting a font file."
+      )
     }
 
     font <- path.expand(font)
@@ -141,7 +188,9 @@ string2fill <- function(
     font_weight <- match.arg(font_weight)
     font_style <- match.arg(font_style)
 
-    tibble::as_tibble(string2fill_family(text, font, font_weight, font_style, tolerance))
+    tibble::as_tibble(
+      string2fill_family(text, font, font_weight, font_style, tolerance)
+    )
   }
 }
 
